/**
 * Get started:
 * https://learn.sparkfun.com/tutorials/esp32-thing-hookup-guide/
 *
 * Works with LOLIN32 Lite, after installation of ESP32 Arduino Core:
 * In Arduino IDE set:
 * Set Board to "WEMOS LOLIN32"
 * Set Upload Speed 115200
 *
 * Known issues: reports problems with BLE library (not tested whether BLE works)
 *
 * Code based on:
 * https://examples.blynk.cc/?board=ESP32&shield=ESP32%20WiFi&example=GettingStarted%2FBlynkBlink&auth=123
 * (goto https://examples.blynk.cc/ select Board: ESP32, connection ESP32 Wifi
 *
 * Fjodor: Added DHT sensor, for ESP boards, included ESP version of library!:
 * Sketch > Include Library > Manage Libraries, search for "DHT", pick "DHT sensor library for ESPx"
 * Example: https://github.com/beegee-tokyo/DHTesp/blob/master/examples/DHT_ESP32/DHT_ESP32.ino
 */

/*************************************************************
  Download latest Blynk library here:
    https://github.com/blynkkk/blynk-library/releases/latest

  Blynk is a platform with iOS and Android apps to control
  Arduino, Raspberry Pi and the likes over the Internet.
  You can easily build graphic interfaces for all your
  projects by simply dragging and dropping widgets.

    Downloads, docs, tutorials: http://www.blynk.cc
    Sketch generator:           http://examples.blynk.cc
    Blynk community:            http://community.blynk.cc
    Follow us:                  http://www.fb.com/blynkapp
                                http://twitter.com/blynk_app

  Blynk library is licensed under MIT license
  This example code is in public domain.

 *************************************************************

  You’ll need:
   - Blynk App (download from AppStore or Google Play)
   - ESP32 board
   - Decide how to connect to Blynk
     (USB, Ethernet, Wi-Fi, Bluetooth, ...)

  There is a bunch of great example sketches included to show you how to get
  started. Think of them as LEGO bricks  and combine them as you wish.
  For example, take the Ethernet Shield sketch and combine it with the
  Servo example, or choose a USB sketch and add a code from SendData
  example.
 *************************************************************/

/* Comment this out to disable prints and save space */
#define BLYNK_PRINT Serial


#include <WiFi.h>
#include <WiFiClient.h>
#include <BlynkSimpleEsp32.h>
#include "DHTesp.h"

DHTesp dht;

// Generally, you should use "unsigned long" for variables that hold time
unsigned long previousMillis = 0;        // will store last temp was read
const long interval = 2000;              // interval at which to read sensor

// You should get Auth Token in the Blynk App.
// Go to the Project Settings (nut icon).
char auth[] = "********";

// Your WiFi credentials.
// Set password to "" for open networks.
char ssid[] = "mspot";
char pass[] = "********";

WidgetLCD lcd(V1);

void setup()
{
  // Debug console
  Serial.begin(9600);

  dht.setup(0, DHTesp::DHT11); // configure it as a DHT11 on pin 0

  Blynk.begin(auth, ssid, pass);

  lcd.clear();
}

void loop()
{
  Blynk.run();
  // You can inject your own code or combine it with other sketches.
  // Check other examples on how to communicate with Blynk. Remember
  // to avoid delay() function!

  unsigned long currentMillis = millis();

  if(currentMillis - previousMillis >= interval) {
      // save the last time you read the sensor
      previousMillis = currentMillis;   // Reading temperature or humidity takes about 250 milliseconds!
      // Sensor readings may also be up to 2 seconds 'old' (its a very slow sensor)
      TempAndHumidity newValues = dht.getTempAndHumidity();

      // Check if reads succesful, then print
      // Check if any reads failed and exit early (to try again).
      if (dht.getStatus() == 0) {
        // print the values in the lcd widget in the Blynk App:
        lcd.print(0,0, "Humidity: " + String(newValues.humidity) + "\nTemp.: "+String(newValues.temperature) );
      }
      else
        Serial.println("DHT11 error status: " + String(dht.getStatusString()));
  }
}
